Trait tween::TweenValue
source · pub trait TweenValue: Copy + Debug + Add<Output = Self> + Sub<Output = Self> {
// Required method
fn scale(self, scale: f32) -> Self;
}Expand description
A TweenValue is a value which can be Tweened. The library fundamentally outputs
TweenValue eventually.
If you want to implement your own values to be tweened (for example, your favorite color lib), then you’ll need to implement this trait.
For now, we require Copy, but can reduce this to a Clone implementation. Please file an
issue if that is needed for your workflow.
Required Methods
Object Safety
This trait is not object safe.